<?php
/**
 * Pixatres functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package Pixatres
 */

if ( ! defined( '_PIXATRES_VERSION' ) ) {
	// Replace the version number of the theme on each release.
	define( '_PIXATRES_VERSION', '1.0.4' );
}

if ( ! function_exists( 'pixatres_setup' ) ) :
	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 *
	 * Note that this function is hooked into the after_setup_theme hook, which
	 * runs before the init hook. The init hook is too late for some features, such
	 * as indicating support for post thumbnails.
	 */
	function pixatres_setup() {
		/*
		 * Make theme available for translation.
		 * Translations can be filed in the /languages/ directory.
		 * If you're building a theme based on Pixatres, use a find and replace
		 * to change 'pixatres' to the name of your theme in all the template files.
		 */
		load_theme_textdomain( 'pixatres', get_template_directory() . '/languages' );

		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );

		/*
		 * Let WordPress manage the document title.
		 * By adding theme support, we declare that this theme does not use a
		 * hard-coded <title> tag in the document head, and expect WordPress to
		 * provide it for us.
		 */
		add_theme_support( 'title-tag' );

		/*
		 * Enable support for Post Thumbnails on posts and pages.
		 *
		 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		 */
		add_theme_support( 'post-thumbnails' );

		// This theme uses wp_nav_menu() in one location.
		register_nav_menus(
			array(
				'menu-1' => esc_html__( 'Primary', 'pixatres' ),
				'menu-top' => esc_html__( 'Top', 'pixatres' ),
				'mobile' => esc_html__( 'Mobile Menu', 'pixatres' ),
				'social' => esc_html__( 'Social Networks', 'pixatres' ),
			)
		);

		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
		add_theme_support(
			'html5',
			array(
				'search-form',
				'comment-form',
				'comment-list',
				'gallery',
				'caption',
				'style',
				'script',
			)
		);

		// Set up the WordPress core custom background feature.
		add_theme_support(
			'custom-background',
			apply_filters(
				'pixatres_custom_background_args',
				array(
					'default-color' => 'ffffff',
					'default-image' => '',
				)
			)
		);

		// Add theme support for selective refresh for widgets.
		add_theme_support( 'customize-selective-refresh-widgets' );

		/**
		 * Add support for core custom logo.
		 *
		 * @link https://codex.wordpress.org/Theme_Logo
		 */
		add_theme_support(
			'custom-logo',
			array(
				'height'      => 250,
				'width'       => 250,
				'flex-width'  => true,
				'flex-height' => true,
			)
		);
		
		add_image_size( 'pixatres-thumbnail-4x3', '400', '300', true );
		
	}
endif;
add_action( 'after_setup_theme', 'pixatres_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function pixatres_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'pixatres_content_width', 768 );
}
add_action( 'after_setup_theme', 'pixatres_content_width', 0 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function pixatres_widgets_init() {
	register_sidebar(
		array(
			'name'          => esc_html__( 'Sidebar', 'pixatres' ),
			'id'            => 'sidebar-1',
			'description'   => esc_html__( 'Add widgets here.', 'pixatres' ),
			'before_widget' => '<section id="%1$s" class="widget %2$s">',
			'after_widget'  => '</section>',
			'before_title'  => '<h2 class="widget-title">',
			'after_title'   => '</h2>',
		)
	);
	register_sidebar(
		array(
			'name'          => esc_html__( 'Footer Widgets Area 1', 'pixatres' ),
			'id'            => 'footer-1',
			'description'   => esc_html__( 'Add widgets here.', 'pixatres' ),
			'before_widget' => '<section id="%1$s" class="widget %2$s">',
			'after_widget'  => '</section>',
			'before_title'  => '<div class="widget-title">',
			'after_title'   => '</div>',
		)
	);
	register_sidebar(
		array(
			'name'          => esc_html__( 'Footer Widgets Area 2', 'pixatres' ),
			'id'            => 'footer-2',
			'description'   => esc_html__( 'Add widgets here.', 'pixatres' ),
			'before_widget' => '<section id="%1$s" class="widget %2$s">',
			'after_widget'  => '</section>',
			'before_title'  => '<div class="widget-title">',
			'after_title'   => '</div>',
		)
	);
	register_sidebar(
		array(
			'name'          => esc_html__( 'Footer Widgets Area 3', 'pixatres' ),
			'id'            => 'footer-3',
			'description'   => esc_html__( 'Add widgets here.', 'pixatres' ),
			'before_widget' => '<section id="%1$s" class="widget %2$s">',
			'after_widget'  => '</section>',
			'before_title'  => '<div class="widget-title">',
			'after_title'   => '</div>',
		)
	);
}
add_action( 'widgets_init', 'pixatres_widgets_init' );

/**
 * Enqueue scripts and styles.
 */
function pixatres_scripts() {
	wp_enqueue_style( 'pixatres-style', get_stylesheet_uri(), array(), _PIXATRES_VERSION );
		
	wp_enqueue_style('bootstrap', get_template_directory_uri() . '/lib/bootstrap/bootstrap.min.css'); 
	wp_enqueue_style('fontawesome', get_template_directory_uri() . '/lib/font-awesome/css/all.min.css'); 
	wp_enqueue_style('owl-carousel-css', get_template_directory_uri() . '/lib/owl-carousel/dist/assets/owl.carousel.min.css'); 
	wp_enqueue_style('owl-carousel-theme-css', get_template_directory_uri() . '/lib/owl-carousel/dist/assets/owl.theme.default.min.css'); 
	wp_enqueue_style('sidr-dark-css', get_template_directory_uri() . '/lib/sidr/stylesheets/jquery.sidr.dark.min.css'); 
	wp_enqueue_style('pixatres-primary-font', '//fonts.googleapis.com/css2?family=Barlow:wght@100;200;300;400;500;600;700;900&display=swap' );
	wp_enqueue_style('pixatres-secondary-font', '//fonts.googleapis.com/css2?family=Lora:wght@300;400;500;600;700&display=swap' );
	wp_enqueue_style('pixatres-core', get_template_directory_uri() . '/design-files/core/core.css'); 
	wp_enqueue_style('pixatres-header', get_template_directory_uri() . '/design-files/header/header.css'); 
	wp_enqueue_style('pixatres-blog-style1', get_template_directory_uri() . '/design-files/blog-style/blog-style1.css'); 
	wp_enqueue_style('pixatres-single', get_template_directory_uri() . '/design-files/single/single.css');
	wp_enqueue_style('pixatres-sidebar', get_template_directory_uri() . '/design-files/sidebar/sidebar.css'); 
	wp_enqueue_style('pixatres-footer', get_template_directory_uri() . '/design-files/footer/footer.css'); 
	wp_enqueue_style('pixatres-featured-modules', get_template_directory_uri() . '/design-files/featured-modules/featured-modules.css'); 

	
	wp_enqueue_script( 'pixatres-navigation', get_template_directory_uri() . '/js/navigation.js', array(), _PIXATRES_VERSION, true );
	wp_enqueue_script( 'owl-carousel', get_template_directory_uri() . '/lib/owl-carousel/dist/owl.carousel.js', array('jquery'), '2.3.4', true );
	wp_enqueue_script( 'sidr', get_template_directory_uri() . '/lib/sidr/jquery.sidr.min.js', array('jquery'), '2.2.1', true );
	wp_enqueue_script( 'pixatres-theme-js', get_template_directory_uri() . '/js/theme.js', array('sidr','owl-carousel'), _PIXATRES_VERSION, true );


	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'pixatres_scripts' );

/**
 * Filter the excerpt length to 50 words.
 *
 * @param int $length Excerpt length.
 * @return int 
 */
function pixatres_excerpt_length( $length ) {
	if ( ! is_admin() ) {
		return 30;
	} else {
		return $length;
	}
}
add_filter( 'excerpt_length', 'pixatres_excerpt_length', 999 );

function pixatres_excerpt_more( $more ) {
	if ( ! is_admin() ) {
		return '....';
	} else {
		return $more;
	}
}
add_filter( 'excerpt_more', 'pixatres_excerpt_more' );
/**
 * Function to wrap the entire site in a container and bootstrap row.
 *
 */
function pixatres_after_header_divs() {
	?><div class="container">
		<div class="row"><?php
}
add_action('pixatres_after_header','pixatres_after_header_divs'); 

function pixatres_before_footer_divs() {
	?></div><!--#.row-->
	</div><!--.container--><?php
}
add_action( 'pixatres_before_footer', 'pixatres_before_footer_divs' );


/**
 * Featured Carousel & Other Modules
 */
function pixatres_insert_carousel() {
	if (is_home())
		get_template_part( 'template-parts/featured-modules/owl-carousel' );
}
add_action('pixatres_after_header','pixatres_insert_carousel'); 

function pixatres_insert_featured_modules() {
	if (is_home()) :
		$i = 0;
		for ($i = 1; $i < 6; $i++) :
			pixatres_display_featured_module( get_theme_mod( 'pixatres-fa-style-'.$i, 'style1' ), get_theme_mod('pixatres-fa-enable-'.$i, 0) ,get_theme_mod( 'pixatres-fa-cat-'.$i, 0 ), get_theme_mod( 'pixatres-fa-show-title-'.$i, true ));
		endfor;
	endif;	
}
add_action('pixatres_after_header','pixatres_insert_featured_modules'); 


/**
 * Function to alter the width of sidebar and content area.
 *
 */
function pixatres_primary_width() {
	$setting = get_theme_mod('pixatres-primary-width', 'right-sidebar');
	switch ($setting) {
		case 'no-sidebar':
			$class = 'col-md-12';
			break;
		case 'right-sidebar':
			$class = 'col-md-8';
			break;
		case 'right-sidebar-narrow':
			$class = 'col-md-9';
			break;
		default:
			$class = 'col-md-8';
			break;					
	}
	echo esc_html($class); 
}
add_action('pixatres_primary_width_class','pixatres_primary_width');

function pixatres_secondary_width() {
	$setting = get_theme_mod('pixatres-primary-width', 'right-sidebar');
	switch ($setting) {
		case 'no-sidebar':
			$class = 'd-none';
			break;
		case 'right-sidebar':
			$class = 'col-md-4';
			break;
		case 'right-sidebar-narrow':
			$class = 'col-md-3';
			break;
		default:
			$class = 'col-md-4';
			break;					
	}
	echo esc_html($class); 
}
add_action('pixatres_secondary_width_class','pixatres_secondary_width');

/**
 * Implement the Custom Colors feature.
 */
function pixatres_colors_override(){ ?>
 <style>
 	:root {
		 --pixatres-primary: <?php echo esc_html(get_theme_mod('pixatres-primary-color','#e07a5f')); ?>;
		 --pixatres-primary-text: <?php echo esc_html(get_theme_mod('pixatres-primary-text-color','#f9ffe7')); ?>;
		 --pixatres-background-main: <?php echo esc_html("#".get_theme_mod('background_color','ffffff')); ?>;
		 --pixatres-background-darker: <?php echo esc_html(get_theme_mod('pixatres-background-darker-color','#eeeeee')); ?>;
		 
		 --pixatres-secondary: <?php echo esc_html(get_theme_mod('pixatres-secondary-color','#3d405b')); ?>;
		 --pixatres-secondary-dark: <?php echo esc_html(get_theme_mod('pixatres-secondary-dark-color','#33202a')); ?>;
		 
		 --pixatres-text-dark: <?php echo esc_html(get_theme_mod('pixatres-text-dark-color','#111')); ?>;
		 --pixatres-text: <?php echo esc_html(get_theme_mod('pixatres-text-color','#555')); ?>;
		 --pixatres-text-light: <?php echo esc_html(get_theme_mod('pixatres-text-light-color','#777')); ?>;
	 }
 
 </style>
<?php 
}
add_action( 'wp_head', 'pixatres_colors_override' );
/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/display-featured-modules.php';


/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';


/**
 * Functions which enhance the theme by hooking into WordPress.
 */
require get_template_directory() . '/inc/template-functions.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
if ( defined( 'JETPACK__VERSION' ) ) {
	require get_template_directory() . '/inc/jetpack.php';
}

