<?php
/**
 * Pixatres Theme Customizer
 * @package Pixatres
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function pixatres_customize_register( $wp_customize ) {
	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
	$wp_customize->get_setting( 'header_textcolor' )->transport = 'postMessage';

	if ( isset( $wp_customize->selective_refresh ) ) {
		$wp_customize->selective_refresh->add_partial(
			'blogname',
			array(
				'selector'        => '.site-title a',
				'render_callback' => 'pixatres_customize_partial_blogname',
			)
		);
		$wp_customize->selective_refresh->add_partial(
			'blogdescription',
			array(
				'selector'        => '.site-description',
				'render_callback' => 'pixatres_customize_partial_blogdescription',
			)
		);
	}
}
add_action( 'customize_register', 'pixatres_customize_register' );

/**
 * Render the site title for the selective refresh partial.
 *
 * @return void
 */
function pixatres_customize_partial_blogname() {
	bloginfo( 'name' );
}

/**
 * Render the site tagline for the selective refresh partial.
 *
 * @return void
 */
function pixatres_customize_partial_blogdescription() {
	bloginfo( 'description' );
}

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function pixatres_customize_preview_js() {
	wp_enqueue_script( 'pixatres-customizer', get_template_directory_uri() . '/inc/customizer/js/customizer.js', array( 'customize-preview' ), _PIXATRES_VERSION, true );
}
add_action( 'customize_preview_init', 'pixatres_customize_preview_js' );

function pixatres_customizer_assets() {
	wp_enqueue_script( 'pixatres-controls-js', get_template_directory_uri() . '/inc/customizer/js/controls.js', array( 'customize-preview' ), _PIXATRES_VERSION, true );
	wp_enqueue_style( 'pixatres-controls-css', get_template_directory_uri() . '/inc/customizer/css/customizer.css' );
}
add_action('customize_controls_enqueue_scripts','pixatres_customizer_assets');

//Custom Controls
if (class_exists('WP_Customize_Control')) {
	//Category Chooser
	class pixatres_WP_Customize_Category_Control extends WP_Customize_Control {
		/**
		 * Render the control's content.
		 */
		public function render_content() {
			$dropdown = wp_dropdown_categories(
				array(
					'name'              => '_customize-dropdown-categories-' . $this->id,
					'echo'              => 0,
					'show_option_none'  => __( 'All', 'pixatres' ),
					'option_none_value' => '0',
					'selected'          => $this->value(),
				)
			);
	
			$dropdown = str_replace( '<select', '<select ' . $this->get_link(), $dropdown );
	
			printf(
				'<label class="customize-control-select"><span class="customize-control-title">%s</span> %s</label>',
				esc_html($this->label),
				$dropdown
			);
		}
	}
	
	//Radio Image Picker
	class pixatres_Image_Radio_Control extends WP_Customize_Control {
	
		public function render_content() {
	
			if (empty($this->choices))
				return;
	
			$name = '_customize-radio-' . $this->id;
			?>
			<span class="customize-control-title"><?php echo esc_html($this->label); ?></span>
			<ul class="controls" id='pixatres-img-container'>
				<?php
				foreach ($this->choices as $value => $label) :
					$class = ($this->value() == $value) ? 'pixatres-radio-img-selected pixatres-radio-img-img' : 'pixatres-radio-img-img';
					?>
					<li style="display: inline;">
						<label>
							<input <?php $this->link(); ?>style = 'display:none' type="radio" value="<?php echo esc_attr($value); ?>" name="<?php echo esc_attr($name); ?>" <?php
														  $this->link();
														  checked($this->value(), $value);
														  ?> />
							<img src='<?php echo esc_url($label); ?>' class='<?php echo esc_attr($class); ?>' />
						</label>
					</li>
					<?php
				endforeach;
				?>
			</ul>
			<?php
		}
	}
	
	class pixatres_infobox_control extends WP_Customize_Control {
		public $type = 'infobox';
		public function render_content(){
			?>
			<div class="infobox">
				<span class="customize-control-title infobox_label"><?php echo esc_html( $this->label ); ?></span>
				<p><?php echo wp_kses_post($this->description); ?></p>
			</div>
			<?php
		}
	}
}


//Import Other sections
require_once get_template_directory()."/inc/customizer/colors.php";
require_once get_template_directory()."/inc/customizer/basic-settings.php";
require_once get_template_directory()."/inc/customizer/featured-areas.php";
require_once get_template_directory()."/inc/customizer/sidebar.php";

require_once get_template_directory()."/inc/customizer/sanitize-functions.php";
